@@ -26,7 +26,7 @@ class Horde_HashTable_Driver_MemcacheTest extends Horde_HashTable_Driver_TestBas
 {
     public static function setUpBeforeClass()
     {
-        if (extension_loaded('memcache') &&
+        if ((extension_loaded('memcache') || extension_loaded('memcached')) &&
             ($config = self::getConfig('HASHTABLE_MEMCACHE_TEST_CONFIG', __DIR__ . '/..')) &&
             isset($config['hashtable']['memcache'])) {
             $memcache = new Horde_Memcache(
